@@ -47,7 +47,7 @@ static const GimpToggleActionEntry cursor_info_toggle_actions[] =
   { "cursor-info-sample-merged", NULL,
     NC_("cursor-info-action", "_Sample Merged"), "",
     NC_("cursor-info-action", "Use the composite color of all visible layers"),
-    G_CALLBACK (cursor_info_sample_merged_cmd_callback),
+    cursor_info_sample_merged_cmd_callback,
     TRUE,
     GIMP_HELP_POINTER_INFO_SAMPLE_MERGED }
 };
