@@ -48,7 +48,6 @@
 
 #include "core/core-types.h"
 
-#include "config/gimplangrc.h"
 #include "config/gimprc.h"
 
 #include "gegl/gimp-gegl.h"
@@ -68,7 +67,6 @@
 
 #include "app.h"
 #include "errors.h"
-#include "language.h"
 #include "sanity.h"
 #include "gimp-debug.h"
 
@@ -189,8 +187,6 @@ app_run (const gchar         *full_prog_name,
   GFile              *default_folder = NULL;
   GFile              *gimpdir;
   const gchar        *abort_message;
-  GimpLangRc         *temprc;
-  gchar              *language   = NULL;
   GError             *font_error = NULL;
 
   if (filenames && filenames[0] && ! filenames[1] &&
@@ -213,26 +209,6 @@ app_run (const gchar         *full_prog_name,
       filenames = NULL;
     }
 
-  /* Language needs to be determined first, before any GimpContext is
-   * instantiated (which happens when the Gimp object is created)
-   * because its properties need to be properly localized in the
-   * settings language (if different from system language). Otherwise we
-   * end up with pieces of GUI always using the system language (cf. bug
-   * 787457). Therefore we do a first pass on "gimprc" file for the sole
-   * purpose of getting the settings language, so that we can initialize
-   * it before anything else.
-   */
-  temprc = gimp_lang_rc_new (alternate_system_gimprc,
-                             alternate_gimprc,
-                             be_verbose);
-  language = gimp_lang_rc_get_language (temprc);
-  g_object_unref (temprc);
-
-  /*  change the locale if a language if specified  */
-  language_init (language);
-  if (language)
-    g_free (language);
-
   /*  Create an instance of the "Gimp" object which is the root of the
    *  core object system
    */
