@@ -247,6 +247,9 @@ _("Export IPTC metadata by default.")
 #define GENERATE_BACKTRACE_BLURB \
 _("Try generating debug data for bug reporting when appropriate.")
 
+#define WIN32_POINTER_INPUT_API_BLURB \
+_("Sets the preferred pen and touch input API.")
+
 #define INITIAL_ZOOM_TO_FIT_BLURB \
 _("When enabled, this will ensure that the full image is visible after a " \
   "file is opened, otherwise it will be displayed with a scale of 1:1.")
@@ -682,6 +685,9 @@ _("Show the current foreground and background colors in the toolbox.")
 #define TOOLBOX_FOO_AREA_BLURB \
 _("Show the currently selected brush, pattern and gradient in the toolbox.")
 
+#define TOOLBOX_GROUP_MENU_MODE_BLURB \
+_("Menu mode of grouped tools.")
+
 #define TOOLBOX_GROUPS_BLURB \
 _("Use a single toolbox button for grouped tools.")
 
@@ -689,7 +695,7 @@ _("Use a single toolbox button for grouped tools.")
 _("Show the currently active image in the toolbox.")
 
 #define TOOLBOX_WILBER_BLURB \
-"Show the GIMP mascot at the top of the toolbox."
+_("Show the GIMP mascot at the top of the toolbox.")
 
 #define TRANSPARENCY_TYPE_BLURB \
 _("Sets the manner in which transparency is displayed in images.")
