@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -23,6 +23,7 @@
 #include <string.h>
 
 #include <gio/gio.h>
+#include <gegl.h>
 
 #include "libgimpbase/gimpbase.h"
 #include "libgimpconfig/gimpconfig.h"
@@ -61,7 +62,6 @@ static void         gimp_rc_get_property      (GObject      *object,
                                                GParamSpec   *pspec);
 
 static GimpConfig * gimp_rc_duplicate         (GimpConfig   *object);
-static void         gimp_rc_load              (GimpRc       *rc);
 static gboolean     gimp_rc_idle_save         (GimpRc       *rc);
 static void         gimp_rc_notify            (GimpRc       *rc,
                                                GParamSpec   *param,
@@ -130,17 +130,8 @@ gimp_rc_finalize (GObject *object)
 {
   GimpRc *rc = GIMP_RC (object);
 
-  if (rc->system_gimprc)
-    {
-      g_object_unref (rc->system_gimprc);
-      rc->system_gimprc = NULL;
-    }
-
-  if (rc->user_gimprc)
-    {
-      g_object_unref (rc->user_gimprc);
-      rc->user_gimprc = NULL;
-    }
+  g_clear_object (&rc->system_gimprc);
+  g_clear_object (&rc->user_gimprc);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -230,7 +221,17 @@ gimp_rc_duplicate_unknown_token (const gchar *key,
 static GimpConfig *
 gimp_rc_duplicate (GimpConfig *config)
 {
-  GimpConfig *dup = g_object_new (GIMP_TYPE_RC, NULL);
+  GObject    *gimp;
+  GimpConfig *dup;
+
+  g_object_get (config, "gimp", &gimp, NULL);
+
+  dup = g_object_new (GIMP_TYPE_RC,
+                      "gimp", gimp,
+                      NULL);
+
+  if (gimp)
+    g_object_unref (gimp);
 
   gimp_config_sync (G_OBJECT (config), G_OBJECT (dup), 0);
 
@@ -240,44 +241,6 @@ gimp_rc_duplicate (GimpConfig *config)
   return dup;
 }
 
-static void
-gimp_rc_load (GimpRc *rc)
-{
-  GError *error = NULL;
-
-  g_return_if_fail (GIMP_IS_RC (rc));
-
-  if (rc->verbose)
-    g_print ("Parsing '%s'\n",
-             gimp_file_get_utf8_name (rc->system_gimprc));
-
-  if (! gimp_config_deserialize_gfile (GIMP_CONFIG (rc),
-                                       rc->system_gimprc, NULL, &error))
-    {
-      if (error->code != GIMP_CONFIG_ERROR_OPEN_ENOENT)
-        g_message ("%s", error->message);
-
-      g_clear_error (&error);
-    }
-
-  if (rc->verbose)
-    g_print ("Parsing '%s'\n",
-             gimp_file_get_utf8_name (rc->user_gimprc));
-
-  if (! gimp_config_deserialize_gfile (GIMP_CONFIG (rc),
-                                       rc->user_gimprc, NULL, &error))
-    {
-      if (error->code != GIMP_CONFIG_ERROR_OPEN_ENOENT)
-        {
-          g_message ("%s", error->message);
-
-          gimp_config_file_backup_on_error (rc->user_gimprc, "gimprc", NULL);
-        }
-
-      g_clear_error (&error);
-    }
-}
-
 static gboolean
 gimp_rc_idle_save (GimpRc *rc)
 {
@@ -302,6 +265,7 @@ gimp_rc_notify (GimpRc     *rc,
 
 /**
  * gimp_rc_new:
+ * @gimp:          a #Gimp
  * @system_gimprc: the name of the system-wide gimprc file or %NULL to
  *                 use the standard location
  * @user_gimprc:   the name of the user gimprc file or %NULL to use the
@@ -314,28 +278,78 @@ gimp_rc_notify (GimpRc     *rc,
  * Returns: the new #GimpRc.
  */
 GimpRc *
-gimp_rc_new (GFile    *system_gimprc,
+gimp_rc_new (GObject  *gimp,
+             GFile    *system_gimprc,
              GFile    *user_gimprc,
              gboolean  verbose)
 {
   GimpRc *rc;
 
+  g_return_val_if_fail (G_IS_OBJECT (gimp), NULL);
   g_return_val_if_fail (system_gimprc == NULL || G_IS_FILE (system_gimprc),
                         NULL);
   g_return_val_if_fail (user_gimprc == NULL || G_IS_FILE (user_gimprc),
                         NULL);
 
   rc = g_object_new (GIMP_TYPE_RC,
+                     "gimp",          gimp,
                      "verbose",       verbose,
                      "system-gimprc", system_gimprc,
                      "user-gimprc",   user_gimprc,
                      NULL);
 
-  gimp_rc_load (rc);
+  gimp_rc_load_system (rc);
+  gimp_rc_load_user (rc);
 
   return rc;
 }
 
+void
+gimp_rc_load_system (GimpRc *rc)
+{
+  GError *error = NULL;
+
+  g_return_if_fail (GIMP_IS_RC (rc));
+
+  if (rc->verbose)
+    g_print ("Parsing '%s'\n",
+             gimp_file_get_utf8_name (rc->system_gimprc));
+
+  if (! gimp_config_deserialize_gfile (GIMP_CONFIG (rc),
+                                       rc->system_gimprc, NULL, &error))
+    {
+      if (error->code != GIMP_CONFIG_ERROR_OPEN_ENOENT)
+        g_message ("%s", error->message);
+
+      g_clear_error (&error);
+    }
+}
+
+void
+gimp_rc_load_user (GimpRc *rc)
+{
+  GError *error = NULL;
+
+  g_return_if_fail (GIMP_IS_RC (rc));
+
+  if (rc->verbose)
+    g_print ("Parsing '%s'\n",
+             gimp_file_get_utf8_name (rc->user_gimprc));
+
+  if (! gimp_config_deserialize_gfile (GIMP_CONFIG (rc),
+                                       rc->user_gimprc, NULL, &error))
+    {
+      if (error->code != GIMP_CONFIG_ERROR_OPEN_ENOENT)
+        {
+          g_message ("%s", error->message);
+
+          gimp_config_file_backup_on_error (rc->user_gimprc, "gimprc", NULL);
+        }
+
+      g_clear_error (&error);
+    }
+}
+
 void
 gimp_rc_set_autosave (GimpRc   *rc,
                       gboolean  autosave)
@@ -407,7 +421,7 @@ gimp_rc_query (GimpRc      *rc,
   if (prop_spec)
     {
       GString *str   = g_string_new (NULL);
-      GValue   value = { 0, };
+      GValue   value = G_VALUE_INIT;
 
       g_value_init (&value, prop_spec->value_type);
       g_object_get_property (rc_object, prop_spec->name, &value);
@@ -488,9 +502,10 @@ gimp_rc_set_unknown_token (GimpRc      *rc,
 void
 gimp_rc_save (GimpRc *rc)
 {
-  GimpRc *global;
-  gchar  *header;
-  GError *error = NULL;
+  GObject *gimp;
+  GimpRc  *global;
+  gchar   *header;
+  GError  *error = NULL;
 
   const gchar *top =
     "GIMP gimprc\n"
@@ -506,7 +521,14 @@ gimp_rc_save (GimpRc *rc)
 
   g_return_if_fail (GIMP_IS_RC (rc));
 
-  global = g_object_new (GIMP_TYPE_RC, NULL);
+  g_object_get (rc, "gimp", &gimp, NULL);
+
+  global = g_object_new (GIMP_TYPE_RC,
+                         "gimp", gimp,
+                         NULL);
+
+  if (gimp)
+    g_object_unref (gimp);
 
   gimp_config_deserialize_gfile (GIMP_CONFIG (global),
                                  rc->system_gimprc, NULL, NULL);
@@ -556,7 +578,7 @@ gimp_rc_migrate (GimpRc *rc)
 
       if (GIMP_IS_PARAM_SPEC_CONFIG_PATH (pspec))
         {
-          GValue value = { 0, };
+          GValue value = G_VALUE_INIT;
 
           g_value_init (&value, pspec->value_type);
 
