@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -30,11 +30,11 @@
 #include "gimpbrush-header.h"
 #include "gimpbrush-load.h"
 #include "gimpbrush-private.h"
+#include "gimppattern-header.h"
 #include "gimptempbuf.h"
 
 #include "gimp-intl.h"
 
-
 /* stuff from abr2gbr Copyright (C) 2001 Marco Lamberto <lm@sunnyspot.org>  */
 /* the above is GPL  see http://the.sunnyspot.org/gimp/  */
 
@@ -103,6 +103,7 @@ static gboolean    abr_reach_8bim_section        (GDataInputStream  *input,
                                                   GError           **error);
 static gboolean    abr_rle_decode                (GDataInputStream  *input,
                                                   gchar             *buffer,
+                                                  gsize              buffer_size,
                                                   gint32             height,
                                                   GError           **error);
 
@@ -134,15 +135,14 @@ gimp_brush_load_brush (GimpContext   *context,
                        GInputStream  *input,
                        GError       **error)
 {
-  GimpBrush   *brush;
-  gint         bn_size;
-  BrushHeader  header;
-  gchar       *name = NULL;
-  guchar      *pixmap;
-  guchar      *mask;
-  gsize        bytes_read;
-  gssize       i, size;
-  gboolean     success = TRUE;
+  GimpBrush       *brush;
+  gsize            bn_size;
+  GimpBrushHeader  header;
+  gchar           *name = NULL;
+  guchar          *mask;
+  gsize            bytes_read;
+  gssize           i, size;
+  gboolean         success = TRUE;
 
   g_return_val_if_fail (G_IS_FILE (file), NULL);
   g_return_val_if_fail (G_IS_INPUT_STREAM (input), NULL);
@@ -188,6 +188,16 @@ gimp_brush_load_brush (GimpContext   *context,
       return NULL;
     }
 
+  if (header.width  > GIMP_BRUSH_MAX_SIZE ||
+      header.height > GIMP_BRUSH_MAX_SIZE ||
+      G_MAXSIZE / header.width / header.height / MAX (4, header.bytes) < 1)
+    {
+      g_set_error (error, GIMP_DATA_ERROR, GIMP_DATA_ERROR_READ,
+                   _("Fatal parse error in brush file: %dx%d over max size."),
+                   header.width, header.height);
+      return NULL;
+    }
+
   switch (header.version)
     {
     case 1:
@@ -216,7 +226,7 @@ gimp_brush_load_brush (GimpContext   *context,
       /*  fallthrough  */
 
     case 2:
-      if (header.magic_number == GBRUSH_MAGIC)
+      if (header.magic_number == GIMP_BRUSH_MAGIC)
         break;
 
     default:
@@ -226,12 +236,29 @@ gimp_brush_load_brush (GimpContext   *context,
       return NULL;
     }
 
+  if (header.header_size < sizeof (GimpBrushHeader))
+    {
+      g_set_error (error, GIMP_DATA_ERROR, GIMP_DATA_ERROR_READ,
+                   _("Unsupported brush format"));
+      return NULL;
+    }
+
   /*  Read in the brush name  */
   if ((bn_size = (header.header_size - sizeof (header))))
     {
       gchar *utf8;
 
-      name = g_new (gchar, bn_size);
+      if (bn_size > GIMP_BRUSH_MAX_NAME)
+        {
+          g_set_error (error, GIMP_DATA_ERROR, GIMP_DATA_ERROR_READ,
+                       _("Invalid header data in '%s': "
+                         "Brush name is too long: %lu"),
+                       gimp_file_get_utf8_name (file),
+                       (gulong) bn_size);
+          return NULL;
+        }
+
+      name = g_new0 (gchar, bn_size + 1);
 
       if (! g_input_stream_read_all (input, name, bn_size,
                                      &bytes_read, NULL, error) ||
@@ -241,14 +268,14 @@ gimp_brush_load_brush (GimpContext   *context,
           return NULL;
         }
 
-      utf8 = gimp_any_to_utf8 (name, -1,
+      utf8 = gimp_any_to_utf8 (name, bn_size - 1,
                                _("Invalid UTF-8 string in brush file '%s'."),
                                gimp_file_get_utf8_name (file));
       g_free (name);
       name = utf8;
     }
 
-  if (!name)
+  if (! name)
     name = g_strdup (_("Unnamed"));
 
   brush = g_object_new (GIMP_TYPE_BRUSH,
@@ -267,8 +294,69 @@ gimp_brush_load_brush (GimpContext   *context,
     {
     case 1:
       success = (g_input_stream_read_all (input, mask, size,
-                                         &bytes_read, NULL, error) &&
+                                          &bytes_read, NULL, error) &&
                  bytes_read == size);
+
+      /* For backwards-compatibility, check if a pattern follows.
+       * The obsolete .gpb format did it this way.
+       */
+      if (success)
+        {
+          GimpPatternHeader ph;
+          goffset           rewind;
+
+          rewind = g_seekable_tell (G_SEEKABLE (input));
+
+          if (g_input_stream_read_all (input, &ph, sizeof (GimpPatternHeader),
+                                       &bytes_read, NULL, NULL) &&
+              bytes_read == sizeof (GimpPatternHeader))
+            {
+              /*  rearrange the bytes in each unsigned int  */
+              ph.header_size  = g_ntohl (ph.header_size);
+              ph.version      = g_ntohl (ph.version);
+              ph.width        = g_ntohl (ph.width);
+              ph.height       = g_ntohl (ph.height);
+              ph.bytes        = g_ntohl (ph.bytes);
+              ph.magic_number = g_ntohl (ph.magic_number);
+
+              if (ph.magic_number == GIMP_PATTERN_MAGIC        &&
+                  ph.version      == 1                         &&
+                  ph.header_size  > sizeof (GimpPatternHeader) &&
+                  ph.bytes        == 3                         &&
+                  ph.width        == header.width              &&
+                  ph.height       == header.height             &&
+                  g_input_stream_skip (input,
+                                       ph.header_size -
+                                       sizeof (GimpPatternHeader),
+                                       NULL, NULL) ==
+                  ph.header_size - sizeof (GimpPatternHeader))
+                {
+                  guchar *pixmap;
+                  gssize  pixmap_size;
+
+                  brush->priv->pixmap =
+                    gimp_temp_buf_new (header.width, header.height,
+                                       babl_format ("R'G'B' u8"));
+
+                  pixmap = gimp_temp_buf_get_data (brush->priv->pixmap);
+
+                  pixmap_size = gimp_temp_buf_get_data_size (brush->priv->pixmap);
+
+                  success = (g_input_stream_read_all (input, pixmap,
+                                                      pixmap_size,
+                                                      &bytes_read, NULL,
+                                                      error) &&
+                             bytes_read == pixmap_size);
+                }
+              else
+                {
+                  /*  seek back if pattern wasn't found  */
+                  success = g_seekable_seek (G_SEEKABLE (input),
+                                             rewind, G_SEEK_SET,
+                                             NULL, error);
+                }
+            }
+        }
       break;
 
     case 2:  /*  cinepaint brush, 16 bit floats  */
@@ -312,26 +400,10 @@ gimp_brush_load_brush (GimpContext   *context,
       }
       break;
 
-    case 3:
-      /* The obsolete .gbp format had a 3-byte pattern following a
-       * 1-byte brush, when embedded in a brush pipe, the current code
-       * tries to load that pattern as a brush, and encounters the '3'
-       * in the header.
-       */
-      g_object_unref (brush);
-      g_set_error (error, GIMP_DATA_ERROR, GIMP_DATA_ERROR_READ,
-                   _("Fatal parse error in brush file:\n"
-                     "Unsupported brush depth %d\n"
-                     "GIMP brushes must be GRAY or RGBA.\n"
-                     "This might be an obsolete GIMP brush file, try "
-                     "loading it as image and save it again."),
-                   header.bytes);
-      return NULL;
-      break;
-
     case 4:
       {
-        guchar buf[8 * 1024];
+        guchar *pixmap;
+        guchar  buf[8 * 1024];
 
         brush->priv->pixmap = gimp_temp_buf_new (header.width, header.height,
                                                  babl_format ("R'G'B' u8"));
@@ -428,6 +500,7 @@ gimp_brush_load_abr (GimpContext   *context,
                                                 file, &my_error);
           break;
 
+        case 10:
         case 6:
           brush_list = gimp_brush_load_abr_v6 (data_input, &abr_hdr,
                                                file, &my_error);
@@ -558,6 +631,14 @@ gimp_brush_load_abr_brush_v12 (GDataInputStream  *input,
   if (error && *error)
     return NULL;
 
+  if (abr_brush_hdr.size < 0)
+    {
+      g_set_error (error, GIMP_DATA_ERROR, GIMP_DATA_ERROR_READ,
+                   _("Fatal parse error in brush file: "
+                     "Brush size value corrupt."));
+      return NULL;
+    }
+
   /*  g_print(" + BRUSH\n | << type: %i  block size: %i bytes\n",
    *          abr_brush_hdr.type, abr_brush_hdr.size);
    */
@@ -568,7 +649,7 @@ gimp_brush_load_abr_brush_v12 (GDataInputStream  *input,
       /* FIXME: support it!
        *
        * We can probabaly feed the info into the generated brush code
-       * and get a useable brush back. It seems to support the same
+       * and get a usable brush back. It seems to support the same
        * types -akl
        */
       g_printerr ("WARNING: computed brush unsupported, skipping.\n");
@@ -632,7 +713,18 @@ gimp_brush_load_abr_brush_v12 (GDataInputStream  *input,
                   abr_sampled_brush_hdr.bounds_long[1]); /* right - left */
         bytes  = abr_sampled_brush_hdr.depth >> 3;
 
-        /* g_print("width %i  height %i\n", width, height); */
+        /* g_print ("width %i  height %i  bytes %i\n", width, height, bytes); */
+
+        if (width  < 1 || width  > 10000 ||
+            height < 1 || height > 10000 ||
+            bytes  < 1 || bytes  > 1     ||
+            G_MAXSIZE / width / height / bytes < 1)
+          {
+            g_set_error (error, GIMP_DATA_ERROR, GIMP_DATA_ERROR_READ,
+                         _("Fatal parse error in brush file: "
+                           "Brush dimensions out of range."));
+            break;
+          }
 
         abr_sampled_brush_hdr.wide = height > 16384;
 
@@ -708,7 +800,7 @@ gimp_brush_load_abr_brush_v12 (GDataInputStream  *input,
           }
         else
           {
-            if (! abr_rle_decode (input, (gchar *) mask, height, error))
+            if (! abr_rle_decode (input, (gchar *) mask, size, height, error))
               {
                 g_object_unref (brush);
                 brush = NULL;
@@ -758,6 +850,14 @@ gimp_brush_load_abr_brush_v6 (GDataInputStream  *input,
   if (error && *error)
     return NULL;
 
+  if (brush_size < 0)
+    {
+      g_set_error (error, GIMP_DATA_ERROR, GIMP_DATA_ERROR_READ,
+                   _("Fatal parse error in brush file: "
+                     "Brush size value corrupt."));
+      return NULL;
+    }
+
   brush_end = brush_size;
 
   /* complement to 4 */
@@ -782,7 +882,7 @@ gimp_brush_load_abr_brush_v6 (GDataInputStream  *input,
   if (! r)
     {
       g_prefix_error (error,
-                      _("Fatal parse error in brush file : "
+                      _("Fatal parse error in brush file: "
                         "File appears truncated: "));
       return NULL;
     }
@@ -794,9 +894,35 @@ gimp_brush_load_abr_brush_v6 (GDataInputStream  *input,
   depth    = abr_read_short (input, error); if (error && *error) return NULL;
   compress = abr_read_char  (input, error); if (error && *error) return NULL;
 
+  depth = depth >> 3;
+
   width  = right - left;
   height = bottom - top;
-  size   = width * (depth >> 3) * height;
+  size   = width * depth * height;
+
+#if 0
+  g_printerr ("width %i  height %i  depth %i  compress %i\n",
+              width, height, depth, compress);
+#endif
+
+  if (width  < 1 || width  > 10000 ||
+      height < 1 || height > 10000 ||
+      depth  < 1 || depth  > 1     ||
+      G_MAXSIZE / width / height / depth < 1)
+    {
+      g_set_error (error, GIMP_DATA_ERROR, GIMP_DATA_ERROR_READ,
+                   _("Fatal parse error in brush file: "
+                     "Brush dimensions out of range."));
+      return NULL;
+    }
+
+  if (compress < 0 || compress > 1)
+    {
+      g_set_error (error, GIMP_DATA_ERROR, GIMP_DATA_ERROR_READ,
+                   _("Fatal parse error in brush file: "
+                     "Unknown compression method."));
+      return NULL;
+    }
 
   tmp = g_path_get_basename (gimp_file_get_utf8_name (file));
   name = g_strdup_printf ("%s-%03d", tmp, index);
@@ -837,15 +963,16 @@ gimp_brush_load_abr_brush_v6 (GDataInputStream  *input,
     }
   else
     {
-      if (! abr_rle_decode (input, (gchar *) mask, height, error))
+      if (! abr_rle_decode (input, (gchar *) mask, size, height, error))
         {
           g_object_unref (brush);
           return NULL;
         }
     }
 
-  g_seekable_seek (G_SEEKABLE (input), next_brush, G_SEEK_SET,
-                   NULL, NULL);
+  if (g_seekable_tell (G_SEEKABLE (input)) <= next_brush)
+    g_seekable_seek (G_SEEKABLE (input), next_brush, G_SEEK_SET,
+                     NULL, NULL);
 
   return brush;
 }
@@ -922,6 +1049,7 @@ abr_supported (AbrHeader  *abr_hdr,
       return TRUE;
       break;
 
+    case 10:
     case 6:
       /* in this case, count contains format sub-version */
       if (abr_hdr->count == 1 || abr_hdr->count == 2)
@@ -949,10 +1077,10 @@ abr_reach_8bim_section (GDataInputStream  *input,
 {
   while (TRUE)
     {
-      gchar  tag[4];
-      gchar  tagname[5];
-      gint32 section_size;
-      gsize  bytes_read;
+      gchar   tag[4];
+      gchar   tagname[5];
+      guint32 section_size;
+      gsize   bytes_read;
 
       if (! g_input_stream_read_all (G_INPUT_STREAM (input),
                                      tag, 4,
@@ -989,39 +1117,45 @@ abr_reach_8bim_section (GDataInputStream  *input,
 static gboolean
 abr_rle_decode (GDataInputStream  *input,
                 gchar             *buffer,
+                gsize              buffer_size,
                 gint32             height,
                 GError           **error)
 {
-  gchar   ch;
-  gint    i, j, c;
-  gshort *cscanline_len;
-  gchar  *data = buffer;
+  gint    i, j;
+  gshort *cscanline_len = NULL;
+  gchar  *cdata         = NULL;
+  gchar  *data          = buffer;
 
   /* read compressed size foreach scanline */
-  cscanline_len = g_new0 (gshort, height);
+  cscanline_len = gegl_scratch_new (gshort, height);
   for (i = 0; i < height; i++)
     {
       cscanline_len[i] = abr_read_short (input, error);
-      if (error && *error)
-        {
-          g_free (cscanline_len);
-          return FALSE;
-        }
+      if ((error && *error) || cscanline_len[i] <= 0)
+        goto err;
     }
 
   /* unpack each scanline data */
   for (i = 0; i < height; i++)
     {
-      for (j = 0; j < cscanline_len[i];)
-        {
-          gint32 n = abr_read_char (input, error);
-          if (error && *error)
-            {
-              g_free (cscanline_len);
-              return FALSE;
-            }
+      gint  len;
+      gsize bytes_read;
 
-          j++;
+      len = cscanline_len[i];
+
+      cdata = gegl_scratch_alloc (len);
+
+      if (! g_input_stream_read_all (G_INPUT_STREAM (input),
+                                     cdata, len,
+                                     &bytes_read, NULL, error) ||
+          bytes_read != len)
+        {
+          goto err;
+        }
+
+      for (j = 0; j < len;)
+        {
+          gint32 n = cdata[j++];
 
           if (n >= 128)     /* force sign */
             n -= 256;
@@ -1034,35 +1168,46 @@ abr_rle_decode (GDataInputStream  *input,
                 continue;
 
               n = -n + 1;
-              ch = abr_read_char (input, error);
-              if (error && *error)
-                {
-                  g_free (cscanline_len);
-                  return FALSE;
-                }
-              j++;
 
-              for (c = 0; c < n; c++, data++)
-                *data = ch;
+              if (j + 1 > len || (data - buffer) + n > buffer_size)
+                goto err;
+
+              memset (data, cdata[j], n);
+
+              j    += 1;
+              data += n;
             }
           else
             {
               /* read the following n + 1 chars (no compr) */
 
-              for (c = 0; c < n + 1; c++, j++, data++)
-                {
-                  *data = abr_read_char (input, error);
-                  if (error && *error)
-                    {
-                      g_free (cscanline_len);
-                      return FALSE;
-                    }
-                }
+              n = n + 1;
+
+              if (j + n > len || (data - buffer) + n > buffer_size)
+                goto err;
+
+              memcpy (data, &cdata[j], n);
+
+              j    += n;
+              data += n;
             }
         }
+
+      g_clear_pointer (&cdata, gegl_scratch_free);
     }
 
-  g_free (cscanline_len);
+  g_clear_pointer (&cscanline_len, gegl_scratch_free);
 
   return TRUE;
+
+err:
+  g_clear_pointer (&cdata, gegl_scratch_free);
+  g_clear_pointer (&cscanline_len, gegl_scratch_free);
+  if (error && ! *error)
+    {
+      g_set_error (error, GIMP_DATA_ERROR, GIMP_DATA_ERROR_READ,
+                   _("Fatal parse error in brush file: "
+                     "RLE compressed brush data corrupt."));
+    }
+  return FALSE;
 }
