@@ -4,9 +4,9 @@
  * gimpbrushclipboard.h
  * Copyright (C) 2006 Michael Natterer <mitch@gimp.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __GIMP_BRUSH_CLIPBOARD_H__
@@ -41,6 +40,7 @@ struct _GimpBrushClipboard
   GimpBrush  parent_instance;
 
   Gimp      *gimp;
+  gboolean   mask_only;
 };
 
 struct _GimpBrushClipboardClass
@@ -51,7 +51,8 @@ struct _GimpBrushClipboardClass
 
 GType      gimp_brush_clipboard_get_type (void) G_GNUC_CONST;
 
-GimpData * gimp_brush_clipboard_new      (Gimp *gimp);
+GimpData * gimp_brush_clipboard_new      (Gimp     *gimp,
+                                          gboolean  mask_only);
 
 
 #endif  /*  __GIMP_BRUSH_CLIPBOARD_H__  */
