@@ -38,8 +38,8 @@ void   gimp_channel_combine_ellipse_rect (GimpChannel    *mask,
                                           gint            y,
                                           gint            w,
                                           gint            h,
-                                          gdouble         a,
-                                          gdouble         b,
+                                          gdouble         rx,
+                                          gdouble         ry,
                                           gboolean        antialias);
 void   gimp_channel_combine_mask         (GimpChannel    *mask,
                                           GimpChannel    *add_on,
