@@ -354,7 +354,7 @@ gimp_histogram_calculate_async (GimpHistogram       *histogram,
     }
 
   histogram->priv->calculate_async = gimp_parallel_run_async (
-    (GimpParallelRunAsyncFunc) gimp_histogram_calculate_internal,
+    (GimpRunAsyncFunc) gimp_histogram_calculate_internal,
     context);
 
   gimp_async_add_callback (
