@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -61,9 +61,20 @@ gimp_image_new_get_last_template (Gimp      *gimp,
 
   if (image)
     {
+      const gchar *comment;
+
+      comment = gimp_template_get_comment (gimp->config->default_image);
+
       gimp_config_sync (G_OBJECT (gimp->config->default_image),
                         G_OBJECT (template), 0);
       gimp_template_set_from_image (template, image);
+
+      /* Do not pass around the comment from the current active comment. Only
+       * pass comments stored in actual templates. This can be even considered
+       * as data leak otherwise (creating 2 images in a row and not realizing
+       * the second will have the metadata comment from the first). See #11384.
+       */
+      g_object_set (template, "comment", comment, NULL);
     }
   else
     {
@@ -120,7 +131,7 @@ gimp_image_new_from_template (Gimp         *gimp,
                                     GIMP_PARASITE_PERSISTENT,
                                     strlen (comment) + 1,
                                     comment);
-      gimp_image_parasite_attach (image, parasite);
+      gimp_image_parasite_attach (image, parasite, FALSE);
       gimp_parasite_free (parasite);
     }
 
@@ -148,7 +159,8 @@ gimp_image_new_from_template (Gimp         *gimp,
   layer = gimp_layer_new (image, width, height,
                           gimp_image_get_layer_format (image, has_alpha),
                           _("Background"),
-                          GIMP_OPACITY_OPAQUE, GIMP_NORMAL_MODE);
+                          GIMP_OPACITY_OPAQUE,
+                          gimp_image_get_default_new_layer_mode (image));
 
   gimp_drawable_fill (GIMP_DRAWABLE (layer),
                       context, gimp_template_get_fill_type (template));
@@ -223,9 +235,12 @@ gimp_image_new_from_drawable (Gimp         *gimp,
   gimp_item_translate (GIMP_ITEM (new_layer), -off_x, -off_y, FALSE);
   gimp_item_set_visible (GIMP_ITEM (new_layer), TRUE, FALSE);
   gimp_item_set_linked (GIMP_ITEM (new_layer), FALSE, FALSE);
-  gimp_layer_set_mode (new_layer, GIMP_NORMAL_MODE, FALSE);
+  gimp_layer_set_mode (new_layer,
+                       gimp_image_get_default_new_layer_mode (new_image),
+                       FALSE);
   gimp_layer_set_opacity (new_layer, GIMP_OPACITY_OPAQUE, FALSE);
-  gimp_layer_set_lock_alpha (new_layer, FALSE, FALSE);
+  if (gimp_layer_can_lock_alpha (new_layer))
+    gimp_layer_set_lock_alpha (new_layer, FALSE, FALSE);
 
   gimp_image_add_layer (new_image, new_layer, NULL, 0, TRUE);
 
@@ -282,48 +297,45 @@ gimp_image_new_from_component (Gimp            *gimp,
 
 GimpImage *
 gimp_image_new_from_buffer (Gimp       *gimp,
-                            GimpImage  *invoke,
-                            GimpBuffer *paste)
+                            GimpBuffer *buffer)
 {
   GimpImage        *image;
   GimpLayer        *layer;
   const Babl       *format;
   gboolean          has_alpha;
+  gdouble           res_x;
+  gdouble           res_y;
   GimpColorProfile *profile;
 
   g_return_val_if_fail (GIMP_IS_GIMP (gimp), NULL);
-  g_return_val_if_fail (invoke == NULL || GIMP_IS_IMAGE (invoke), NULL);
-  g_return_val_if_fail (GIMP_IS_BUFFER (paste), NULL);
+  g_return_val_if_fail (GIMP_IS_BUFFER (buffer), NULL);
 
-  format    = gimp_buffer_get_format (paste);
+  format    = gimp_buffer_get_format (buffer);
   has_alpha = babl_format_has_alpha (format);
 
   image = gimp_create_image (gimp,
-                             gimp_buffer_get_width  (paste),
-                             gimp_buffer_get_height (paste),
+                             gimp_buffer_get_width  (buffer),
+                             gimp_buffer_get_height (buffer),
                              gimp_babl_format_get_base_type (format),
                              gimp_babl_format_get_precision (format),
                              TRUE);
   gimp_image_undo_disable (image);
 
-  if (invoke)
+  if (gimp_buffer_get_resolution (buffer, &res_x, &res_y))
     {
-      gdouble xres;
-      gdouble yres;
-
-      gimp_image_get_resolution (invoke, &xres, &yres);
-      gimp_image_set_resolution (image, xres, yres);
-      gimp_image_set_unit (image, gimp_image_get_unit (invoke));
+      gimp_image_set_resolution (image, res_x, res_y);
+      gimp_image_set_unit (image, gimp_buffer_get_unit (buffer));
     }
 
-  profile = gimp_buffer_get_color_profile (paste);
+  profile = gimp_buffer_get_color_profile (buffer);
   gimp_image_set_color_profile (image, profile, NULL);
 
-  layer = gimp_layer_new_from_buffer (paste, image,
+  layer = gimp_layer_new_from_buffer (buffer, image,
                                       gimp_image_get_layer_format (image,
                                                                    has_alpha),
                                       _("Pasted Layer"),
-                                      GIMP_OPACITY_OPAQUE, GIMP_NORMAL_MODE);
+                                      GIMP_OPACITY_OPAQUE,
+                                      gimp_image_get_default_new_layer_mode (image));
 
   gimp_image_add_layer (image, layer, NULL, 0, TRUE);
 
@@ -381,7 +393,8 @@ gimp_image_new_from_pixbuf (Gimp        *gimp,
                                       gimp_image_get_layer_format (new_image,
                                                                    has_alpha),
                                       layer_name,
-                                      GIMP_OPACITY_OPAQUE, GIMP_NORMAL_MODE);
+                                      GIMP_OPACITY_OPAQUE,
+                                      gimp_image_get_default_new_layer_mode (new_image));
 
   gimp_image_add_layer (new_image, layer, NULL, 0, TRUE);
 
