@@ -1095,7 +1095,7 @@ gimp_palette_load_ase (GimpContext   *context,
 
           /* Convert 4 bytes to a 32bit float value */
           tmp = GINT32_FROM_BE (tmp);
-          pixels[j] = *(gfloat *) &tmp;
+          memcpy (&pixels[j], &tmp, 4);
         }
 
       if (! valid_color)
@@ -1206,7 +1206,7 @@ gimp_palette_load_css (GimpContext   *context,
   g_return_val_if_fail (G_IS_INPUT_STREAM (input), NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-  regex = g_regex_new (".*color.*:(?P<param>.*);", G_REGEX_CASELESS, 0, error);
+  regex = g_regex_new (".*color.*:(?P<param>.*)", G_REGEX_CASELESS, 0, error);
   if (! regex)
     return NULL;
 
