@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __GIMP_STROKE_OPTIONS_H__
@@ -74,7 +74,7 @@ void                gimp_stroke_options_take_dash_pattern    (GimpStrokeOptions
 
 void                gimp_stroke_options_prepare              (GimpStrokeOptions *options,
                                                               GimpContext       *context,
-                                                              gboolean           use_default_values);
+                                                              GimpPaintOptions  *paint_options);
 void                gimp_stroke_options_finish               (GimpStrokeOptions *options);
 
 
