@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __IMAGE_NEW_DIALOG_H__
@@ -21,7 +21,7 @@
 
 GtkWidget * image_new_dialog_new (GimpContext  *context);
 
-void        image_new_dialog_set (GtkWidget    *widget,
+void        image_new_dialog_set (GtkWidget    *dialog,
                                   GimpImage    *image,
                                   GimpTemplate *template);
 
