@@ -48,6 +48,7 @@
 
 #include "widgets/gimpwidgets-utils.h"
 
+#include "gimpcanvascanvasboundary.h"
 #include "gimpcanvasguide.h"
 #include "gimpcanvaslayerboundary.h"
 #include "gimpcanvaspath.h"
@@ -89,6 +90,10 @@ static void   gimp_display_shell_name_changed_handler       (GimpImage        *i
 static void   gimp_display_shell_selection_invalidate_handler
                                                             (GimpImage        *image,
                                                              GimpDisplayShell *shell);
+static void   gimp_display_shell_component_visibility_changed_handler
+                                                            (GimpImage        *image,
+                                                             GimpChannelType   channel,
+                                                             GimpDisplayShell *shell);
 static void   gimp_display_shell_size_changed_detailed_handler
                                                             (GimpImage        *image,
                                                              gint              previous_origin_x,
@@ -173,6 +178,9 @@ static void   gimp_display_shell_quality_notify_handler     (GObject          *c
 static void  gimp_display_shell_color_config_notify_handler (GObject          *config,
                                                              GParamSpec       *param_spec,
                                                              GimpDisplayShell *shell);
+static void  gimp_display_shell_display_changed_handler     (GimpContext      *context,
+                                                             GimpDisplay      *display,
+                                                             GimpDisplayShell *shell);
 
 
 /*  public functions  */
@@ -184,6 +192,7 @@ gimp_display_shell_connect (GimpDisplayShell *shell)
   GimpContainer     *vectors;
   GimpDisplayConfig *config;
   GimpColorConfig   *color_config;
+  GimpContext       *user_context;
   GList             *list;
 
   g_return_if_fail (GIMP_IS_DISPLAY_SHELL (shell));
@@ -198,6 +207,8 @@ gimp_display_shell_connect (GimpDisplayShell *shell)
   config       = shell->display->config;
   color_config = GIMP_CORE_CONFIG (config)->color_management;
 
+  user_context = gimp_get_user_context (shell->display->gimp);
+
   g_signal_connect (image, "clean",
                     G_CALLBACK (gimp_display_shell_clean_dirty_handler),
                     shell);
@@ -219,6 +230,9 @@ gimp_display_shell_connect (GimpDisplayShell *shell)
   g_signal_connect (image, "selection-invalidate",
                     G_CALLBACK (gimp_display_shell_selection_invalidate_handler),
                     shell);
+  g_signal_connect (image, "component-visibility-changed",
+                    G_CALLBACK (gimp_display_shell_component_visibility_changed_handler),
+                    shell);
   g_signal_connect (image, "size-changed-detailed",
                     G_CALLBACK (gimp_display_shell_size_changed_detailed_handler),
                     shell);
@@ -375,6 +389,10 @@ gimp_display_shell_connect (GimpDisplayShell *shell)
                     G_CALLBACK (gimp_display_shell_color_config_notify_handler),
                     shell);
 
+  g_signal_connect (user_context, "display-changed",
+                    G_CALLBACK (gimp_display_shell_display_changed_handler),
+                    shell);
+
   gimp_display_shell_active_vectors_handler     (image, shell);
   gimp_display_shell_invalidate_preview_handler (image, shell);
   gimp_display_shell_quick_mask_changed_handler (image, shell);
@@ -386,6 +404,16 @@ gimp_display_shell_connect (GimpDisplayShell *shell)
 
   gimp_canvas_layer_boundary_set_layer (GIMP_CANVAS_LAYER_BOUNDARY (shell->layer_boundary),
                                         gimp_image_get_active_layer (image));
+
+  gimp_canvas_canvas_boundary_set_image (GIMP_CANVAS_CANVAS_BOUNDARY (shell->canvas_boundary),
+                                         image);
+
+  if (shell->show_all)
+    {
+      gimp_image_inc_show_all_count (image);
+
+      gimp_image_flush (image);
+    }
 }
 
 void
@@ -395,6 +423,7 @@ gimp_display_shell_disconnect (GimpDisplayShell *shell)
   GimpContainer     *vectors;
   GimpDisplayConfig *config;
   GimpColorConfig   *color_config;
+  GimpContext       *user_context;
   GList             *list;
 
   g_return_if_fail (GIMP_IS_DISPLAY_SHELL (shell));
@@ -409,11 +438,20 @@ gimp_display_shell_disconnect (GimpDisplayShell *shell)
   config       = shell->display->config;
   color_config = GIMP_CORE_CONFIG (config)->color_management;
 
+  user_context = gimp_get_user_context (shell->display->gimp);
+
   gimp_display_shell_icon_update_stop (shell);
 
   gimp_canvas_layer_boundary_set_layer (GIMP_CANVAS_LAYER_BOUNDARY (shell->layer_boundary),
                                         NULL);
 
+  gimp_canvas_canvas_boundary_set_image (GIMP_CANVAS_CANVAS_BOUNDARY (shell->canvas_boundary),
+                                         NULL);
+
+  g_signal_handlers_disconnect_by_func (user_context,
+                                        gimp_display_shell_display_changed_handler,
+                                        shell);
+
   g_signal_handlers_disconnect_by_func (color_config,
                                         gimp_display_shell_color_config_notify_handler,
                                         shell);
@@ -531,6 +569,9 @@ gimp_display_shell_disconnect (GimpDisplayShell *shell)
   g_signal_handlers_disconnect_by_func (image,
                                         gimp_display_shell_resolution_changed_handler,
                                         shell);
+  g_signal_handlers_disconnect_by_func (image,
+                                        gimp_display_shell_component_visibility_changed_handler,
+                                        shell);
   g_signal_handlers_disconnect_by_func (image,
                                         gimp_display_shell_size_changed_detailed_handler,
                                         shell);
@@ -549,6 +590,13 @@ gimp_display_shell_disconnect (GimpDisplayShell *shell)
   g_signal_handlers_disconnect_by_func (image,
                                         gimp_display_shell_clean_dirty_handler,
                                         shell);
+
+  if (shell->show_all)
+    {
+      gimp_image_dec_show_all_count (image);
+
+      gimp_image_flush (image);
+    }
 }
 
 
@@ -778,6 +826,15 @@ gimp_display_shell_sample_point_move_handler (GimpImage        *image,
   gimp_canvas_sample_point_set (item, x, y);
 }
 
+static void
+gimp_display_shell_component_visibility_changed_handler (GimpImage        *image,
+                                                         GimpChannelType   channel,
+                                                         GimpDisplayShell *shell)
+{
+  if (channel == GIMP_CHANNEL_ALPHA && shell->show_all)
+    gimp_display_shell_expose_full (shell);
+}
+
 static void
 gimp_display_shell_size_changed_detailed_handler (GimpImage        *image,
                                                   gint              previous_origin_x,
@@ -827,7 +884,11 @@ gimp_display_shell_size_changed_detailed_handler (GimpImage        *image,
                                             shell->offset_x + scaled_previous_origin_x,
                                             shell->offset_y + scaled_previous_origin_y);
 
-      gimp_display_shell_scroll_center_image (shell, horizontally, vertically);
+      if (! gimp_display_shell_get_infinite_canvas (shell))
+        {
+          gimp_display_shell_scroll_center_image (shell,
+                                                  horizontally, vertically);
+        }
 
       /* The above calls might not lead to a call to
        * gimp_display_shell_scroll_clamp_and_update() and
@@ -1167,3 +1228,12 @@ gimp_display_shell_color_config_notify_handler (GObject          *config,
       shell->color_config_set = FALSE;
     }
 }
+
+static void
+gimp_display_shell_display_changed_handler (GimpContext      *context,
+                                            GimpDisplay      *display,
+                                            GimpDisplayShell *shell)
+{
+  if (shell->display == display)
+    gimp_display_shell_update_priority_rect (shell);
+}
