@@ -23,7 +23,8 @@
 
 
 gboolean gimp_update_auto_check (GimpCoreConfig *config);
-gboolean gimp_update_check      (GimpCoreConfig *config);
+void     gimp_update_check      (GimpCoreConfig *config);
+void     gimp_update_refresh    (GimpCoreConfig *config);
 
 
 #endif /* __APP_GIMP_UPDATE_H__ */
