@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -200,8 +200,9 @@ gimp_operation_border_set_property (GObject      *object,
 static void
 gimp_operation_border_prepare (GeglOperation *operation)
 {
-  gegl_operation_set_format (operation, "input",  babl_format ("Y float"));
-  gegl_operation_set_format (operation, "output", babl_format ("Y float"));
+  const Babl *space = gegl_operation_get_source_space (operation, "input");
+  gegl_operation_set_format (operation, "input",  babl_format_with_space ("Y float", space));
+  gegl_operation_set_format (operation, "output", babl_format_with_space ("Y float", space));
 }
 
 static GeglRectangle
@@ -338,8 +339,8 @@ gimp_operation_border_process (GeglOperation       *operation,
    * them on jaycox@gimp.org
    */
   GimpOperationBorder *self          = GIMP_OPERATION_BORDER (operation);
-  const Babl          *input_format  = babl_format ("Y float");
-  const Babl          *output_format = babl_format ("Y float");
+  const Babl          *input_format  = gegl_operation_get_format (operation, "input");
+  const Babl          *output_format = gegl_operation_get_format (operation, "output");
 
   gint32 i, j, x, y;
 
