@@ -15,12 +15,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 
 /* Implementation of the Flood algorithm.
- * See http://wiki.gimp.org/wiki/Algorithms:Flood for details.
+ * See https://wiki.gimp.org/wiki/Algorithms:Flood for details.
  */
 
 
@@ -238,7 +238,7 @@ gimp_operation_flood_class_init (GimpOperationFloodClass *klass)
                                  "name",        "gimp:flood",
                                  "categories",  "gimp",
                                  "description", "GIMP Flood operation",
-                                 "reference", "http://wiki.gimp.org/wiki/Algorithms:Flood",
+                                 "reference", "https://wiki.gimp.org/wiki/Algorithms:Flood",
                                  "reference-image", "flood-output.png",
                                  "reference-composition", reference_xml,
                                  NULL);
@@ -258,8 +258,9 @@ gimp_operation_flood_init (GimpOperationFlood *self)
 static void
 gimp_operation_flood_prepare (GeglOperation *operation)
 {
-  gegl_operation_set_format (operation, "input",  babl_format ("Y float"));
-  gegl_operation_set_format (operation, "output", babl_format ("Y float"));
+  const Babl *space = gegl_operation_get_source_space (operation, "input");
+  gegl_operation_set_format (operation, "input",  babl_format_with_space ("Y float", space));
+  gegl_operation_set_format (operation, "output", babl_format_with_space ("Y float", space));
 }
 
 static GeglRectangle
@@ -781,7 +782,7 @@ gimp_operation_flood_process_propagate_horizontal (GimpOperationFloodContext
                                GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);
             }
 
-          /* The new water level is the maximum of the curernt ground level,
+          /* The new water level is the maximum of the current ground level,
            * and the minimum of the current and previous water levels.  Recall
            * that `level` holds the previous water level, and that the current
            * water level is never less than the ground level.
@@ -993,8 +994,8 @@ gimp_operation_flood_process (GeglOperation       *operation,
                               const GeglRectangle *roi,
                               gint                 level)
 {
-  const Babl                   *input_format  = babl_format ("Y float");
-  const Babl                   *output_format = babl_format ("Y float");
+  const Babl                   *input_format  = gegl_operation_get_format (operation, "input");
+  const Babl                   *output_format = gegl_operation_get_format (operation, "output");
   GeglColor                    *color;
   gint                          max_size;
   GimpOperationFloodContext     ctx;
