@@ -391,16 +391,22 @@ gimp_paint_core_start (GimpPaintCore     *core,
   if (core->undo_buffer)
     g_object_unref (core->undo_buffer);
 
-  core->undo_buffer = gegl_buffer_dup (gimp_drawable_get_buffer (drawable));
+  core->undo_buffer = gimp_gegl_buffer_dup (gimp_drawable_get_buffer (drawable));
+
+  /*  Set the image pickable  */
+  if (! core->show_all)
+    core->image_pickable = GIMP_PICKABLE (image);
+  else
+    core->image_pickable = GIMP_PICKABLE (gimp_image_get_projection (image));
 
   /*  Allocate the saved proj structure  */
   g_clear_object (&core->saved_proj_buffer);
 
   if (core->use_saved_proj)
     {
-      GeglBuffer *buffer = gimp_pickable_get_buffer (GIMP_PICKABLE (image));
+      GeglBuffer *buffer = gimp_pickable_get_buffer (core->image_pickable);
 
-      core->saved_proj_buffer = gegl_buffer_dup (buffer);
+      core->saved_proj_buffer = gimp_gegl_buffer_dup (buffer);
     }
 
   /*  Allocate the canvas blocks structure  */
@@ -511,7 +517,8 @@ gimp_paint_core_finish (GimpPaintCore *core,
                                 gimp_item_get_height (GIMP_ITEM (drawable)),
                                 &rect.x, &rect.y, &rect.width, &rect.height);
 
-      gimp_gegl_rectangle_align_to_tile_grid (&rect, &rect, core->undo_buffer);
+      gegl_rectangle_align_to_buffer (&rect, &rect, core->undo_buffer,
+                                      GEGL_RECTANGLE_ALIGNMENT_SUPERSET);
 
       gimp_image_undo_group_start (image, GIMP_UNDO_GROUP_PAINT,
                                    core->undo_desc);
@@ -535,6 +542,8 @@ gimp_paint_core_finish (GimpPaintCore *core,
       gimp_image_undo_group_end (image);
     }
 
+  core->image_pickable = NULL;
+
   g_clear_object (&core->undo_buffer);
   g_clear_object (&core->saved_proj_buffer);
 
@@ -566,11 +575,18 @@ gimp_paint_core_cancel (GimpPaintCore *core,
                                 gimp_item_get_height (GIMP_ITEM (drawable)),
                                 &x, &y, &width, &height))
     {
+      GeglRectangle rect;
+
+      gegl_rectangle_align_to_buffer (&rect,
+                                      GEGL_RECTANGLE (x, y, width, height),
+                                      gimp_drawable_get_buffer (drawable),
+                                      GEGL_RECTANGLE_ALIGNMENT_SUPERSET);
+
       gimp_gegl_buffer_copy (core->undo_buffer,
-                             GEGL_RECTANGLE (x, y, width, height),
+                             &rect,
                              GEGL_ABYSS_NONE,
                              gimp_drawable_get_buffer (drawable),
-                             GEGL_RECTANGLE (x, y, width, height));
+                             &rect);
     }
 
   g_clear_object (&core->undo_buffer);
@@ -611,6 +627,23 @@ gimp_paint_core_interpolate (GimpPaintCore    *core,
                                                  paint_options, time);
 }
 
+void
+gimp_paint_core_set_show_all (GimpPaintCore *core,
+                              gboolean       show_all)
+{
+  g_return_if_fail (GIMP_IS_PAINT_CORE (core));
+
+  core->show_all = show_all;
+}
+
+gboolean
+gimp_paint_core_get_show_all (GimpPaintCore *core)
+{
+  g_return_val_if_fail (GIMP_IS_PAINT_CORE (core), FALSE);
+
+  return core->show_all;
+}
+
 void
 gimp_paint_core_set_current_coords (GimpPaintCore    *core,
                                     const GimpCoords *coords)
@@ -735,6 +768,15 @@ gimp_paint_core_get_paint_buffer (GimpPaintCore    *core,
   return paint_buffer;
 }
 
+GimpPickable *
+gimp_paint_core_get_image_pickable (GimpPaintCore *core)
+{
+  g_return_val_if_fail (GIMP_IS_PAINT_CORE (core), NULL);
+  g_return_val_if_fail (core->image_pickable != NULL, NULL);
+
+  return core->image_pickable;
+}
+
 GeglBuffer *
 gimp_paint_core_get_orig_image (GimpPaintCore *core)
 {
@@ -1045,9 +1087,10 @@ gimp_paint_core_replace (GimpPaintCore            *core,
                                                 core->paint_buffer_y,
                                                 width, height);
 
-          gimp_gegl_rectangle_align_to_tile_grid (
+          gegl_rectangle_align_to_buffer (
             &aligned_combined_mask_rect, &combined_mask_rect,
-            gimp_drawable_get_buffer (drawable));
+            gimp_drawable_get_buffer (drawable),
+            GEGL_RECTANGLE_ALIGNMENT_SUPERSET);
 
           combined_mask_buffer = gegl_buffer_new (&aligned_combined_mask_rect,
                                                   babl_format ("Y float"));
