@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __GIMP_VECTORS_IMPORT_H__
@@ -23,7 +23,7 @@
 
 
 gboolean  gimp_vectors_import_file   (GimpImage    *image,
-                                      const gchar  *filename,
+                                      GFile        *file,
                                       gboolean      merge,
                                       gboolean      scale,
                                       GimpVectors  *parent,
