@@ -4,9 +4,9 @@
  * gimpdataeditor.h
  * Copyright (C) 2002-2004 Michael Natterer <mitch@gimp.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __GIMP_DATA_EDITOR_H__
@@ -49,8 +48,7 @@ struct _GimpDataEditor
 
   GtkWidget       *name_entry;
 
-  GtkWidget       *save_button;
-  GtkWidget       *revert_button;
+  GtkWidget       *view; /* filled by subclasses */
 };
 
 struct _GimpDataEditorClass
