@@ -284,8 +284,6 @@
 #define GIMP_HELP_PATH_EXPORT                     "gimp-path-export"
 #define GIMP_HELP_PATH_EDIT                       "gimp-path-edit"
 
-#define GIMP_HELP_TOOLS_DIALOG                    "gimp-tools-dialog"
-
 #define GIMP_HELP_TOOL_AIRBRUSH                   "gimp-tool-airbrush"
 #define GIMP_HELP_TOOL_ALIGN                      "gimp-tool-align"
 #define GIMP_HELP_TOOL_BRIGHTNESS_CONTRAST        "gimp-tool-brightness-contrast"
@@ -299,7 +297,6 @@
 #define GIMP_HELP_TOOL_CONVOLVE                   "gimp-tool-convolve"
 #define GIMP_HELP_TOOL_CROP                       "gimp-tool-crop"
 #define GIMP_HELP_TOOL_CURVES                     "gimp-tool-curves"
-#define GIMP_HELP_TOOL_CURVES                     "gimp-tool-curves"
 #define GIMP_HELP_TOOL_DODGE_BURN                 "gimp-tool-dodge-burn"
 #define GIMP_HELP_TOOL_ELLIPSE_SELECT             "gimp-tool-ellipse-select"
 #define GIMP_HELP_TOOL_ERASER                     "gimp-tool-eraser"
@@ -333,6 +330,7 @@
 #define GIMP_HELP_TOOL_SMUDGE                     "gimp-tool-smudge"
 #define GIMP_HELP_TOOL_TEXT                       "gimp-tool-text"
 #define GIMP_HELP_TOOL_THRESHOLD                  "gimp-tool-threshold"
+#define GIMP_HELP_TOOL_TRANSFORM_3D               "gimp-tool-transform-3d"
 #define GIMP_HELP_TOOL_UNIFIED_TRANSFORM          "gimp-tool-unified-transform"
 #define GIMP_HELP_TOOL_VECTORS                    "gimp-tool-vectors"
 #define GIMP_HELP_TOOL_WARP                       "gimp-tool-warp"
@@ -399,7 +397,7 @@
 #define GIMP_HELP_FILTER_LINEAR_SINUSOID          "gimp-filter-linear-sinusoid"
 #define GIMP_HELP_FILTER_LITTLE_PLANET            "gimp-filter-little-planet"
 #define GIMP_HELP_FILTER_LONG_SHADOW              "gimp-filter-long-shadow"
-#define GIMP_HELP_FILTER_MANTIUK_2006             "gimp-filter-manituk-2006"
+#define GIMP_HELP_FILTER_MANTIUK_2006             "gimp-filter-mantiuk-2006"
 #define GIMP_HELP_FILTER_MAZE                     "gimp-filter-maze"
 #define GIMP_HELP_FILTER_MEAN_CURVATURE_BLUR      "gimp-filter-mean-curvature-blur"
 #define GIMP_HELP_FILTER_MEDIAN_BLUR              "gimp-filter-median-blur"
@@ -695,7 +693,6 @@
 #define GIMP_HELP_DOCK_IMAGE_MENU                 "gimp-dock-image-menu"
 #define GIMP_HELP_DOCK_AUTO_BUTTON                "gimp-dock-auto-button"
 #define GIMP_HELP_DOCK_CHANGE_SCREEN              "gimp-dock-change-screen"
-#define GIMP_HELP_DOCK_SEPARATOR                  "gimp-dock-separator"
 
 #define GIMP_HELP_DOCK_TAB_ADD                    "gimp-dock-tab-add"
 #define GIMP_HELP_DOCK_TAB_CLOSE                  "gimp-dock-tab-close"
@@ -714,7 +711,6 @@
 #define GIMP_HELP_DEVICE_STATUS_DIALOG            "gimp-device-status-dialog"
 #define GIMP_HELP_DISPLAY_FILTER_DIALOG           "gimp-display-filter-dialog"
 #define GIMP_HELP_HISTOGRAM_DIALOG                "gimp-histogram-dialog"
-#define GIMP_HELP_INFO_DIALOG                     "gimp-info-dialog"
 #define GIMP_HELP_MODULE_DIALOG                   "gimp-module-dialog"
 #define GIMP_HELP_NAVIGATION_DIALOG               "gimp-navigation-dialog"
 #define GIMP_HELP_SYMMETRY_DIALOG                 "gimp-symmetry-dialog"
@@ -736,17 +732,26 @@
 #define GIMP_HELP_HELP                            "gimp-help"
 #define GIMP_HELP_HELP_CONTEXT                    "gimp-help-context"
 
+/* Most of the colordisplay, colorselector and controller id's below are not
+   used since they are needed in /libgimpwidgets/ or /modules/ where this can't
+   be used. Instead the strings are used there directly.
+   We define them here anyway, to make gimp-help aware of them.
+ */
+#define GIMP_HELP_COLORDISPLAY_CLIP               "gimp-colordisplay-clip"
 #define GIMP_HELP_COLORDISPLAY_COLORBLIND         "gimp-colordisplay-colorblind"
 #define GIMP_HELP_COLORDISPLAY_CONTRAST           "gimp-colordisplay-contrast"
 #define GIMP_HELP_COLORDISPLAY_GAMMA              "gimp-colordisplay-gamma"
-#define GIMP_HELP_COLORDISPLAY_GIMP               "gimp-colordisplay-gimp"
-#define GIMP_HELP_COLORDISPLAY_PROOF              "gimp-colordisplay-proof"
 
 #define GIMP_HELP_COLORSELECTOR_CMYK              "gimp-colorselector-cmyk"
+#define GIMP_HELP_COLORSELECTOR_GIMP              "gimp-colorselector-gimp"
+#define GIMP_HELP_COLORSELECTOR_NOTEBOOK          "gimp-colorselector-notebook"
+#define GIMP_HELP_COLORSELECTOR_PALETTE           "gimp-colorselector-palette"
+#define GIMP_HELP_COLORSELECTOR_SCALES            "gimp-colorselector-scales"
 #define GIMP_HELP_COLORSELECTOR_TRIANGLE          "gimp-colorselector-triangle"
-#define GIMP_HELP_COLORSELECTOR_WATER             "gimp-colorselector-water"
+#define GIMP_HELP_COLORSELECTOR_WATERCOLOR        "gimp-colorselector-watercolor"
 
 #define GIMP_HELP_CONTROLLER_KEYBOARD             "gimp-controller-keyboard"
+#define GIMP_HELP_CONTROLLER_DIRECTX_DIRECTINPUT  "gimp-controller-directx-directinput"
 #define GIMP_HELP_CONTROLLER_LINUX_INPUT          "gimp-controller-linux-input"
 #define GIMP_HELP_CONTROLLER_MIDI                 "gimp-controller-midi"
 #define GIMP_HELP_CONTROLLER_MOUSE                "gimp-controller-mouse"
