@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __GIMP_PROGRESS_BOX_H__
@@ -36,19 +36,19 @@ typedef struct _GimpProgressBoxClass  GimpProgressBoxClass;
 
 struct _GimpProgressBox
 {
-  GtkVBox     parent_instance;
+  GtkBox     parent_instance;
 
-  gboolean    active;
-  gboolean    cancelable;
-  gdouble     value;
+  gboolean   active;
+  gboolean   cancellable;
+  gdouble    value;
 
-  GtkWidget  *label;
-  GtkWidget  *progress;
+  GtkWidget *label;
+  GtkWidget *progress;
 };
 
 struct _GimpProgressBoxClass
 {
-  GtkVBoxClass  parent_class;
+  GtkBoxClass  parent_class;
 };
 
 
