@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -30,7 +30,9 @@
 
 #include "gimpdock.h"
 #include "gimpdockable.h"
+#include "gimpdockwindow.h"
 #include "gimpsessioninfo-aux.h"
+#include "gimpsessionmanaged.h"
 
 
 /*  public functions  */
@@ -85,7 +87,7 @@ gimp_session_info_aux_new_from_props (GObject *object,
       if (pspec)
         {
           GString *str   = g_string_new (NULL);
-          GValue   value = { 0, };
+          GValue   value = G_VALUE_INIT;
 
           g_value_init (&value, pspec->value_type);
           g_object_get_property (object, pspec->name, &value);
@@ -144,7 +146,7 @@ gimp_session_info_aux_set_props (GObject *object,
 
               if (pspec)
                 {
-                  GValue  value = { 0, };
+                  GValue  value = G_VALUE_INIT;
 
                   g_value_init (&value, pspec->value_type);
 
@@ -171,7 +173,7 @@ gimp_session_info_aux_set_props (GObject *object,
                     }
                   else
                     {
-                      GValue  str_value = { 0, };
+                      GValue  str_value = G_VALUE_INIT;
 
                       g_value_init (&str_value, G_TYPE_STRING);
                       g_value_set_static_string (&str_value, aux->value);
@@ -280,28 +282,3 @@ gimp_session_info_aux_deserialize (GScanner  *scanner,
 
   return token;
 }
-
-void
-gimp_session_info_aux_set_list (GtkWidget *dialog,
-                                GList     *aux_list)
-{
-  /* FIXME: make the aux-info stuff generic */
-
-  if (GIMP_IS_DOCK (dialog))
-    gimp_dock_set_aux_info (GIMP_DOCK (dialog), aux_list);
-  else if (GIMP_IS_DOCKABLE (dialog))
-    gimp_dockable_set_aux_info (GIMP_DOCKABLE (dialog), aux_list);
-}
-
-GList *
-gimp_session_info_aux_get_list (GtkWidget *dialog)
-{
-  /* FIXME: make the aux-info stuff generic */
-
-  if (GIMP_IS_DOCK (dialog))
-    return gimp_dock_get_aux_info (GIMP_DOCK (dialog));
-  else if (GIMP_IS_DOCKABLE (dialog))
-    return gimp_dockable_get_aux_info (GIMP_DOCKABLE (dialog));
-
-  return NULL;
-}
