@@ -12,16 +12,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __XCF_SEEK_H__
 #define __XCF_SEEK_H__
 
 
-gboolean   xcf_seek_pos (XcfInfo *info,
-                         guint    pos,
-                         GError **error);
+gboolean   xcf_seek_pos (XcfInfo  *info,
+                         goffset   pos,
+                         GError  **error);
 
 
 #endif  /* __XCF_SEEK_H__ */
