@@ -391,8 +391,8 @@ create_dialog (void)
   widget = gimp_dialog_new ("Gimp Dialog",
                             "gimp-widget-dialog",
                             NULL, 0, NULL, NULL,
-                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                            GTK_STOCK_OK,     GTK_RESPONSE_OK,
+                            "_Cancel", GTK_RESPONSE_CANCEL,
+                            "_OK",     GTK_RESPONSE_OK,
 
                             NULL);
 
@@ -471,7 +471,8 @@ create_frame (void)
 
   frame = gimp_frame_new ("Frame");
   content = gtk_label_new ("Frame Content\nThis Frame is HIG compliant");
-  gtk_misc_set_alignment (GTK_MISC (content), 0.0, 0.0);
+  gtk_label_set_xalign (GTK_LABEL (content), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (content), 0.0);
   gtk_container_add (GTK_CONTAINER (frame), content);
 
   return new_widget_info ("gimp-widget-frame", frame, MEDIUM);
