@@ -62,9 +62,7 @@ typedef struct
 
 
 #define GIMP_ASPECT_PREVIEW_GET_PRIVATE(obj) \
-  G_TYPE_INSTANCE_GET_PRIVATE (preview, \
-                               GIMP_TYPE_ASPECT_PREVIEW, \
-                               GimpAspectPreviewPrivate)
+  ((GimpAspectPreviewPrivate *) gimp_aspect_preview_get_instance_private ((GimpAspectPreview *) (preview)))
 
 static void  gimp_aspect_preview_constructed  (GObject         *object);
 static void  gimp_aspect_preview_dispose      (GObject         *object);
@@ -101,7 +99,8 @@ static void  gimp_aspect_preview_set_drawable_id
                                                gint32             drawable_ID);
 
 
-G_DEFINE_TYPE (GimpAspectPreview, gimp_aspect_preview, GIMP_TYPE_PREVIEW)
+G_DEFINE_TYPE_WITH_PRIVATE (GimpAspectPreview, gimp_aspect_preview,
+                            GIMP_TYPE_PREVIEW)
 
 #define parent_class gimp_aspect_preview_parent_class
 
@@ -127,8 +126,6 @@ gimp_aspect_preview_class_init (GimpAspectPreviewClass *klass)
   preview_class->transform   = gimp_aspect_preview_transform;
   preview_class->untransform = gimp_aspect_preview_untransform;
 
-  g_type_class_add_private (object_class, sizeof (GimpAspectPreviewPrivate));
-
   /**
    * GimpAspectPreview:drawable:
    *
