@@ -101,6 +101,7 @@ typedef enum
   ARCH_X86_VENDOR_RISE,
   ARCH_X86_VENDOR_UMC,
   ARCH_X86_VENDOR_SIS,
+  ARCH_X86_VENDOR_HYGON,
   ARCH_X86_VENDOR_UNKNOWN    = 0xff
 } X86Vendor;
 
@@ -195,6 +196,8 @@ arch_get_vendor (void)
 #ifdef ARCH_X86_64
   if (strcmp (id.idaschar, "AuthenticAMD") == 0)
     return ARCH_X86_VENDOR_AMD;
+  else if (strcmp (id.idaschar, "HygonGenuine") == 0)
+    return ARCH_X86_VENDOR_HYGON;
   else if (strcmp (id.idaschar, "GenuineIntel") == 0)
     return ARCH_X86_VENDOR_INTEL;
 #else
@@ -202,6 +205,8 @@ arch_get_vendor (void)
     return ARCH_X86_VENDOR_INTEL;
   else if (strcmp (id.idaschar, "AuthenticAMD") == 0)
     return ARCH_X86_VENDOR_AMD;
+  else if (strcmp (id.idaschar, "HygonGenuine") == 0)
+    return ARCH_X86_VENDOR_HYGON;
   else if (strcmp (id.idaschar, "CentaurHauls") == 0)
     return ARCH_X86_VENDOR_CENTAUR;
   else if (strcmp (id.idaschar, "CyrixInstead") == 0)
@@ -406,6 +411,7 @@ arch_accel (void)
       break;
 
     case ARCH_X86_VENDOR_AMD:
+    case ARCH_X86_VENDOR_HYGON:
       caps = arch_accel_amd ();
       break;
 
