@@ -66,15 +66,14 @@ struct _GimpColorSelectorPrivate
 };
 
 #define GET_PRIVATE(obj) \
-        G_TYPE_INSTANCE_GET_PRIVATE (obj, \
-                                     GIMP_TYPE_COLOR_SELECTOR, \
-                                     GimpColorSelectorPrivate)
+        ((GimpColorSelectorPrivate *) gimp_color_selector_get_instance_private ((GimpColorSelector *) (obj)))
 
 
 static void   gimp_color_selector_dispose (GObject *object);
 
 
-G_DEFINE_TYPE (GimpColorSelector, gimp_color_selector, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE (GimpColorSelector, gimp_color_selector,
+                            GTK_TYPE_BOX)
 
 #define parent_class gimp_color_selector_parent_class
 
@@ -134,8 +133,6 @@ gimp_color_selector_class_init (GimpColorSelectorClass *klass)
   klass->channel_changed       = NULL;
   klass->model_visible_changed = NULL;
   klass->set_config            = NULL;
-
-  g_type_class_add_private (object_class, sizeof (GimpColorSelectorPrivate));
 }
 
 static void
