@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library.  If not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -27,6 +27,7 @@
 #include "gimpwidgetstypes.h"
 
 #include "gimpmemsizeentry.h"
+#include "gimpspinbutton.h"
 #include "gimpwidgets.h"
 
 #include "libgimp/libgimp-intl.h"
@@ -58,6 +59,8 @@ static void  gimp_memsize_entry_adj_callback  (GtkAdjustment    *adj,
 static void  gimp_memsize_entry_unit_callback (GtkWidget        *widget,
                                                GimpMemsizeEntry *entry);
 
+static guint64 gimp_memsize_entry_get_rounded_value (GimpMemsizeEntry *entry,
+                                                     guint64           value);
 
 G_DEFINE_TYPE (GimpMemsizeEntry, gimp_memsize_entry, GTK_TYPE_BOX)
 
@@ -117,7 +120,11 @@ gimp_memsize_entry_adj_callback (GtkAdjustment    *adj,
 {
   guint64 size = gtk_adjustment_get_value (adj);
 
-  entry->value = size << entry->shift;
+  if (gimp_memsize_entry_get_rounded_value (entry, entry->value) != size)
+    /* Do not allow losing accuracy if the converted/displayed value
+     * stays the same.
+     */
+    entry->value = size << entry->shift;
 
   g_signal_emit (entry, gimp_memsize_entry_signals[VALUE_CHANGED], 0);
 }
@@ -141,7 +148,7 @@ gimp_memsize_entry_unit_callback (GtkWidget        *widget,
       entry->shift = shift;
 
       gtk_adjustment_configure (entry->adjustment,
-                                CAST entry->value >> shift,
+                                gimp_memsize_entry_get_rounded_value (entry, entry->value),
                                 CAST entry->lower >> shift,
                                 CAST entry->upper >> shift,
                                 gtk_adjustment_get_step_increment (entry->adjustment),
@@ -152,6 +159,35 @@ gimp_memsize_entry_unit_callback (GtkWidget        *widget,
 #undef CAST
 }
 
+/**
+ * gimp_memsize_entry_get_rounded_value:
+ * @entry: #GimpMemsizeEntry whose set unit is used.
+ * @value: value to convert to @entry unit, and rounded.
+ *
+ * Returns: the proper integer value to be displayed for current unit.
+ *          This value has been appropriately rounded to the nearest
+ *          integer, away from zero.
+ */
+static guint64
+gimp_memsize_entry_get_rounded_value (GimpMemsizeEntry *entry,
+                                      guint64           value)
+{
+  guint64 converted;
+
+#if _MSC_VER < 1300
+#  define CAST (gint64)
+#else
+#  define CAST
+#endif
+
+  converted = (CAST value >> entry->shift) +
+              ((CAST entry->value >> (entry->shift - 1)) & 1);
+
+#undef CAST
+
+  return converted;
+}
+
 
 /**
  * gimp_memsize_entry_new:
@@ -195,12 +231,13 @@ gimp_memsize_entry_new (guint64  value,
   entry->upper = upper;
   entry->shift = shift;
 
-  adj = (GtkAdjustment *) gtk_adjustment_new (CAST (value >> shift),
+  adj = (GtkAdjustment *) gtk_adjustment_new (gimp_memsize_entry_get_rounded_value (entry,
+                                                                                    entry->value),
                                               CAST (lower >> shift),
                                               CAST (upper >> shift),
                                               1, 8, 0);
 
-  entry->spinbutton = gtk_spin_button_new (adj, 1.0, 0);
+  entry->spinbutton = gimp_spin_button_new (adj, 1.0, 0);
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (entry->spinbutton), TRUE);
 
 #undef CAST
@@ -216,9 +253,9 @@ gimp_memsize_entry_new (guint64  value,
                     G_CALLBACK (gimp_memsize_entry_adj_callback),
                     entry);
 
-  entry->menu = gimp_int_combo_box_new (_("Kilobytes"), 10,
-                                        _("Megabytes"), 20,
-                                        _("Gigabytes"), 30,
+  entry->menu = gimp_int_combo_box_new (_("Kibibyte"), 10,
+                                        _("Mebibyte"), 20,
+                                        _("Gibibyte"), 30,
                                         NULL);
 
   gimp_int_combo_box_set_active (GIMP_INT_COMBO_BOX (entry->menu), shift);
@@ -258,20 +295,10 @@ gimp_memsize_entry_set_value (GimpMemsizeEntry *entry,
     }
 
   if (shift != entry->shift)
-    {
-      entry->shift = shift;
-      entry->value = value;
+    gimp_int_combo_box_set_active (GIMP_INT_COMBO_BOX (entry->menu), shift);
 
-      gimp_int_combo_box_set_active (GIMP_INT_COMBO_BOX (entry->menu), shift);
-    }
-
-#if _MSC_VER < 1300
-#  define CAST (gint64)
-#else
-#  define CAST
-#endif
-
-  gtk_adjustment_set_value (entry->adjustment, CAST (value >> shift));
+  gtk_adjustment_set_value (entry->adjustment,
+                            (gdouble) gimp_memsize_entry_get_rounded_value (entry, value));
 
 #undef CASE
 }
