@@ -35,6 +35,11 @@
 #endif
 
 #if MAC_OS_X_VERSION_MAX_ALLOWED < 1070
+#if MAC_OS_X_VERSION_MAX_ALLOWED < 1060
+@protocol NSWindowDelegate
+@end
+#endif
+
 @interface NSWindow (GIMPExt)
 - (NSRect) convertRectToScreen: (NSRect)aRect;
 @end
@@ -54,6 +59,10 @@
 {
   GimpPickButton *button;
   NSMutableArray *windows;
+#ifndef __LP64__
+  BOOL firstBecameKey;
+  NSCursor *cursor;
+#endif
 }
 
 @property (nonatomic, assign) BOOL firstBecameKey;
@@ -68,6 +77,9 @@
 {
   GimpPickButton *button;
   GimpPickWindowController *controller;
+#ifndef __LP64__
+  NSTrackingArea *area;
+#endif
 }
 
 @property (readonly,assign) NSTrackingArea *area;
@@ -192,7 +204,7 @@
   rect = [self.window convertRectToScreen:rect];
   rect.origin.y = [[[NSScreen screens] objectAtIndex:0] frame].size.height - rect.origin.y;
 
-  root_image_ref = CGWindowListCreateImage (rect,
+  root_image_ref = CGWindowListCreateImage (NSRectToCGRect(rect),
                                             kCGWindowListOptionOnScreenOnly,
                                             kCGNullWindowID,
                                             kCGWindowImageDefault);
