@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library.  If not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -60,7 +60,8 @@ gimp_unit_combo_box_class_init (GimpUnitComboBoxClass *klass)
 
   gtk_widget_class_install_style_property (widget_class,
                                            g_param_spec_double ("label-scale",
-                                                                NULL, NULL,
+                                                                "Label Scale",
+                                                                "The scale for the text cell renderer",
                                                                 0.0,
                                                                 G_MAXDOUBLE,
                                                                 1.0,
