@@ -330,11 +330,11 @@ cdisplay_colorblind_convert_buffer (GimpColorDisplay *display,
 
   iter = gegl_buffer_iterator_new (buffer, area, 0,
                                    babl_format ("RGBA float") /* linear! */,
-                                   GEGL_ACCESS_READWRITE, GEGL_ABYSS_NONE);
+                                   GEGL_ACCESS_READWRITE, GEGL_ABYSS_NONE, 1);
 
   while (gegl_buffer_iterator_next (iter))
     {
-      gfloat *data  = iter->data[0];
+      gfloat *data  = iter->items[0].data;
       gint    count = iter->length;
 
       while (count--)
