@@ -1020,7 +1020,10 @@ pnm_load_rawpfm (PNMScanner *scan,
            * little vague about what the scale factor should be used
            * for */
           data[x] *= fabsf (info->scale_factor);
-          data[x] = fmaxf (0.0f, fminf (FLT_MAX, data[x]));
+          /* Keep values smaller than zero. That is in line with what the
+           * TIFF loader does. If the user doesn't want the negative numbers
+           * he has to get rid of them afterwards */
+          /* data[x] = fmaxf (0.0f, fminf (FLT_MAX, data[x])); */
         }
 
         gegl_buffer_set (buffer,
@@ -1582,6 +1585,15 @@ save_image (GFile     *file,
   status = TRUE;
 
  out:
+  if (! status)
+    {
+      GCancellable  *cancellable = g_cancellable_new ();
+
+      g_cancellable_cancel (cancellable);
+      g_output_stream_close (output, cancellable, NULL);
+      g_object_unref (cancellable);
+    }
+
   if (comment)
     g_free (comment);
   if (buffer)
@@ -1606,8 +1618,8 @@ save_dialog (void)
                                     G_CALLBACK (gimp_radio_button_update),
                                     &psvals.raw, psvals.raw,
 
-                                    _("Raw"),   TRUE,  NULL,
-                                    _("ASCII"), FALSE, NULL,
+                                    _("_Raw"),   TRUE,  NULL,
+                                    _("_ASCII"), FALSE, NULL,
 
                                     NULL);
   gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
