@@ -851,7 +851,7 @@ read_general_image_attribute_block (FILE     *f,
 
   chunk_start = ftell (f);
   if ((psp_ver_major >= 4
-      && (fread (&init_len, 4, 1, f) < 1 || (init_len = GUINT32_FROM_LE (init_len) < 42)))
+      && (fread (&init_len, 4, 1, f) < 1 || ((init_len = GUINT32_FROM_LE (init_len)) < 46)))
       || fread (&ia->width, 4, 1, f) < 1
       || fread (&ia->height, 4, 1, f) < 1
       || fread (&res, 8, 1, f) < 1
@@ -1128,8 +1128,17 @@ read_color_block (FILE      *f,
     }
 
   color_palette_entries = GUINT32_FROM_LE (entry_count);
+  /* TODO: GIMP currently only supports a maximum of 256 colors
+   * in an indexed image. If this changes, we can change this check */
+  if (color_palette_entries > 256)
+    {
+      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
+                   _("Error: Unsupported palette size"));
+      return -1;
+    }
+
   /* psp color palette entries are stored as RGBA so 4 bytes per entry
-     where the fourth bytes is always zero */
+   * where the fourth bytes is always zero */
   pal_size = color_palette_entries * 4;
   color_palette = g_malloc (pal_size);
   if (fread (color_palette, pal_size, 1, f) < 1)
@@ -1498,7 +1507,7 @@ read_channel_data (FILE        *f,
         else
           endq = q + line_width * height;
 
-        buf = g_malloc (127);
+        buf = g_malloc (128);
         while (q < endq)
           {
             fread (&runcount, 1, 1, f);
