@@ -18,7 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -269,7 +269,7 @@ arc_details (GdkPoint *vert_a,
   if (ay == by || by == cy || ay == cy)
     {
       /* Horz line -> midpoint gives inter_y */
-      if (ax == bx && bx == cx)
+      if (ay == by && by == cy)
         {
           /* Straight line */
           double minx = ax;
@@ -334,7 +334,7 @@ static gdouble
 arc_angle (GdkPoint *pnt,
            GdkPoint *center)
 {
-  /* Get angle (in degress) of point given origin of center */
+  /* Get angle (in degrees) of point given origin of center */
   gint16  shift_x;
   gint16  shift_y;
   gdouble offset_angle;
