@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -30,23 +30,23 @@ typedef struct {
    GdkColor normal_bg;
    GdkColor selected_fg;
    GdkColor selected_bg;
+   GdkColor interactive_bg;
+   GdkColor interactive_fg;
 } ColorSelData_t;
 
 typedef struct {
-   gint 		default_map_type;
-   gboolean 		prompt_for_area_info;
-   gboolean 		require_default_url;
-   gboolean 		show_area_handle;
-   gboolean 		keep_circles_round;
-   gboolean 		show_url_tip;
-   gboolean 		use_doublesized;
-   gboolean		auto_convert;
-   gdouble		threshold;
-   gint			undo_levels;
-   gint			mru_size;
-   ColorSelData_t	colors;
-   GdkGC 	       *normal_gc;
-   GdkGC 	       *selected_gc;
+   gint                 default_map_type;
+   gboolean             prompt_for_area_info;
+   gboolean             require_default_url;
+   gboolean             show_area_handle;
+   gboolean             keep_circles_round;
+   gboolean             show_url_tip;
+   gboolean             use_doublesized;
+   gboolean             auto_convert;
+   gdouble              threshold;
+   gint                 undo_levels;
+   gint                 mru_size;
+   ColorSelData_t       colors;
 } PreferencesData_t;
 
 void do_preferences_dialog(void);
