@@ -12,8 +12,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 gboolean print_draw_page (GtkPrintContext *context,
-                          PrintData       *data);
+                          PrintData       *data,
+                          GError         **error);
