@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 
@@ -44,6 +44,8 @@ typedef struct
   GimpUnit            unit;
   gdouble             xres;
   gdouble             yres;
+  gdouble             min_xres;
+  gdouble             min_yres;
   GimpUnit            image_unit;
   gdouble             offset_x;
   gdouble             offset_y;
