@@ -192,6 +192,9 @@ class _ReadLine(object):
 
         return self.modal_raw_input_result
 
+    def modal_input(self, text):
+        return eval(self.modal_raw_input(text))
+
     # Each time the insert mark is modified, move the cursor to it.
     def on_buf_mark_set(self, buffer, iter, mark):
         if mark is not buffer.get_insert():
@@ -278,7 +281,9 @@ class _ReadLine(object):
         keyval = event.keyval
 
         if not state:
-            if keyval == _keys.Return:
+            if keyval == _keys.Escape:
+                pass
+            elif keyval == _keys.Return:
                 self._commit()
             elif keyval == _keys.Up:
                 self.__history(-1)
@@ -341,7 +346,8 @@ class _ReadLine(object):
         cursor line.'''
 
         iter = self.__get_cursor()
-        iter.set_line_offset(len(self.ps))
+        iter.set_line(iter.get_line())
+        iter.forward_chars(len(self.ps))
         return iter
 
     def __get_end(self):
@@ -520,7 +526,8 @@ class _Console(_ReadLine, code.InteractiveInterpreter):
         # this. Therefore, replace this function with our own modal raw
         # input function.
         exec "import __builtin__" in self.locals
-        self.locals['__builtin__'].__dict__['raw_input'] = lambda text: self.modal_raw_input(text)
+        self.locals['__builtin__'].__dict__['raw_input'] = lambda text='': self.modal_raw_input(text)
+        self.locals['__builtin__'].__dict__['input'] = lambda text='': self.modal_input(text)
 
         self.start_script = start_script
         self.completer = completer
@@ -563,6 +570,7 @@ class _Console(_ReadLine, code.InteractiveInterpreter):
 
         self.__start()
         self.run_on_raw_input = start_script
+        self.raw_input(self.ps1)
 
     def do_raw_input(self, text):
         if self.cmd_buffer:
